/*********************************************************************************
**
**   $Id: WOLaborForm.cpp,v 1.4 2004/05/24 12:01:05 croftj Exp $
**   Copyright (c) 2004 Joe Croft <joe@croftj.net>
**   
**   This file is part of ah2.
**
**   ah2 is free software; you can redistribute it and/or modify
**   it under the terms of the GNU General Public License as published by
**   the Free Software Foundation; either version 2 of the License, or
**   (at your option) any later version.
**
**   Foobar is distributed in the hope that it will be useful,
**   but WITHOUT ANY WARRANTY; without even the implied warranty of
**   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**   GNU General Public License for more details.
**
**   You should have received a copy of the GNU General Public License
**   along with Foobar; if not, write to the Free Software
**   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**
*********************************************************************************/

#include <qlistbox.h>
#include <qmessagebox.h>
#include <qregexp.h>
#include <qsqlquery.h>
#include <qvalidator.h>
#include "WOLaborForm.h"

extern QSqlDatabase *autohouse;

WOLaborForm::WOLaborForm(QWidget *pParent, const char *pName, WFlags f) :
           DataForm(autohouse, "wo_labor", 4, 3, pParent, pName, f)
{
   printf("WOLaborForm::WOLaborForm(): Enter()\n");
   fflush(stdout);
   inTransaction = false;
   descrEdit =       new QLineEdit(this);
   woEdit =          new QLineEdit(this);
   laborEdit =       new QLineEdit(this);
   QDoubleValidator *qv = new QDoubleValidator(0.0, 99999.0, 1, this);
   laborEdit->setValidator(qv);

   DataFields fields[] =
   {
      { "workorder", "WorkOrder",      0,  0,  0,  0,  0,  0,  1, "",      woEdit, NULL },
      { "descr",     "Description",    1,  0,  0,  0,  0,  0,  0, "",      descrEdit, NULL },
      { "hours",     "Hours",          2,  0,  0,  0,  0,  0,  0, "",      laborEdit, NULL },
      { "tech",      "Tech",           2,  1,  0,  0,  0,  0,  0, "",      NULL, NULL },
      {  NULL, NULL, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL }
   };
   printf("WOLaborForm::WOLaborForm(): Setting Fields()\n");
   fflush(stdout);
   setFields(fields);
   woEdit->setEnabled(false);
   setEnabled(false);
   printf("WOLaborForm::WOLaborForm(): Exit()\n");
   fflush(stdout);
}

void WOLaborForm::setEnabled(bool b) 
{
   printf("WOLaborForm::setEnabled('%s'): Entry\n", b == 1 ? "true" : "false");
   fflush(stdout);

   descrEdit->setEnabled(b);
   descrEdit->setCursorPosition(0);

   laborEdit->setEnabled(b);
   laborEdit->setCursorPosition(0);

   printf("WOLaborForm::setEnabled(): Exit\n");
   fflush(stdout);
}

void WOLaborForm::deleteRecord() 
{
   QString s;
   printf("WOLaborForm::deleteRecord(): Enter()\n");
   fflush(stdout);
   s = "<qt>Deleting part '" +
        descrEdit->text() +
        "'. This operation can not be undone! Are you sure?</qt>"; 
   printf("WOLaborForm::deleteRecord(): Opening Message Box\n");
   fflush(stdout);
   if (QMessageBox::warning(NULL, "Delete Transaction", s, QMessageBox::Yes | QMessageBox::Default, 
                           QMessageBox::No | QMessageBox::Escape) == QMessageBox::Yes) 
   {
      printf("WOLaborForm::deleteRecord(): deleting record()\n");
      fflush(stdout);
      DataForm::deleteRecord();
   }
   printf("WOLaborForm::deleteRecord(): Exit()\n");
   fflush(stdout);
}

void WOLaborForm::insertRecord()
{
   beginTransaction();
   DataForm::insertRecord();  
   printf("WOLaborEdit::insertRecord(): wo = |%s|\n", (const char *)wo);
   if ( wo != "" ) 
   {
      printf("WOLaborEdit::insertRecord(): Setting owner field = |%s|\n", (const char *)wo);
      woEdit->setText(wo);
   }
   setEnabled(true);
}

void WOLaborForm::updateRecord()
{
   beginTransaction();
   if ( wo != "" ) 
   {
      woEdit->setText(wo);
   }
   DataForm::updateRecord();  
   setEnabled(false);
}

void WOLaborForm::beginTransaction()
{
   if ( ! inTransaction ) 
   {
      DataForm::beginTransaction();
      inTransaction = true;
   }
}

void WOLaborForm::commitTransaction()
{
   if ( inTransaction ) 
   {
      DataForm::commitTransaction();
      inTransaction = false;
   }
}

void WOLaborForm::rollbackTransaction()
{
   if ( inTransaction ) 
   {
      DataForm::rollbackTransaction();
      inTransaction = false;
   }
}

void WOLaborForm::setWorkOrder(QString _wo)
{
   printf("WOLaborForm::setOwner(): Setting wo |%s|\n", (const char *)_wo);
   wo = _wo;
}

bool WOLaborForm::isInTransaction()
{
   printf("WOLaborForm::isInTransaction(): inTransaction = %x\n", inTransaction);
   fflush(stdout);
   return(inTransaction);
}

void WOLaborForm::refresh(QSqlRecord *r)
{
   printf("WOLaborForm::isInTransaction(): Enter, inTransaction = %x\n", inTransaction);
   fflush(stdout);
   DataForm::refresh(r);
   setEnabled(true);
   printf("WOLaborForm::isInTransaction(): Exit\n");
   fflush(stdout);
}

